summaryrefslogtreecommitdiffstats
path: root/ospf6d
diff options
context:
space:
mode:
authorDonald Sharp <sharpd@nvidia.com>2022-02-14 18:52:05 +0100
committerDonald Sharp <sharpd@nvidia.com>2022-02-14 18:52:05 +0100
commitbbf5104c5ba37090c190c8688b14c4a07d00250b (patch)
treeda1def553ce384d5121c5ca02363c9c5b0e64e08 /ospf6d
parentdoc: Fix spelling mistakes (diff)
downloadfrr-bbf5104c5ba37090c190c8688b14c4a07d00250b.tar.xz
frr-bbf5104c5ba37090c190c8688b14c4a07d00250b.zip
ospf6d: Fix spelling mistakes
Signed-off-by: Donald Sharp <sharpd@nvidia.com>
Diffstat (limited to 'ospf6d')
-rw-r--r--ospf6d/ospf6_asbr.c8
-rw-r--r--ospf6d/ospf6_auth_trailer.c2
-rw-r--r--ospf6d/ospf6_top.c2
-rw-r--r--ospf6d/ospf6_zebra.c2
4 files changed, 7 insertions, 7 deletions
diff --git a/ospf6d/ospf6_auth_trailer.c b/ospf6d/ospf6_auth_trailer.c
index 2d0621cc2..5333fdc2f 100644
--- a/ospf6d/ospf6_auth_trailer.c
+++ b/ospf6d/ospf6_auth_trailer.c
@@ -488,7 +488,7 @@ int ospf6_auth_check_digest(struct ospf6_header *oh, struct ospf6_interface *oi,
if (!keychain) {
if (IS_OSPF6_DEBUG_AUTH_RX)
zlog_err(
- "RECV[%s]: Keychain does't exist for %s",
+ "RECV[%s]: Keychain doesn't exist for %s",
oi->interface->name,
ospf6_message_type(oh->type));
return OSPF6_AUTH_VALIDATE_FAILURE;
diff --git a/ospf6d/ospf6_top.c b/ospf6d/ospf6_top.c
index 9381fa7fa..13f16efa6 100644
--- a/ospf6d/ospf6_top.c
+++ b/ospf6d/ospf6_top.c
@@ -2137,7 +2137,7 @@ DEFPY (show_ipv6_ospf6_external_aggregator,
VRF_CMD_HELP_STR
"All VRFs\n"
"Show external summary addresses\n"
- "detailed informtion\n"
+ "detailed information\n"
JSON_STR)
{
bool uj = use_json(argc, argv);
diff --git a/ospf6d/ospf6_zebra.c b/ospf6d/ospf6_zebra.c
index 82d280811..e279d0411 100644
--- a/ospf6d/ospf6_zebra.c
+++ b/ospf6d/ospf6_zebra.c
@@ -354,7 +354,7 @@ DEFUN(show_zebra,
vty_json(vty, json);
} else {
- vty_out(vty, "Zebra Infomation\n");
+ vty_out(vty, "Zebra Information\n");
vty_out(vty, " fail: %d\n", zclient->fail);
vty_out(vty, " redistribute default: %d\n",
vrf_bitmap_check(zclient->default_information[AFI_IP6],
diff --git a/ospf6d/ospf6_asbr.c b/ospf6d/ospf6_asbr.c
index 203ae14f2..1c0d948cc 100644
--- a/ospf6d/ospf6_asbr.c
+++ b/ospf6d/ospf6_asbr.c
@@ -2874,7 +2874,7 @@ ospf6_originate_summary_lsa(struct ospf6 *ospf6,
if (IS_OSPF6_DEBUG_AGGR)
zlog_debug("%s: Aggr LSA ID: %d flags %x.",
__func__, aggr->id, aggr->aggrflags);
/* Dont originate external LSA,
* If it is configured not to advertise.
*/
if (CHECK_FLAG(aggr->aggrflags, OSPF6_EXTERNAL_AGGRT_NO_ADVERTISE)) {
@@ -3248,11 +3248,11 @@ static void ospf6_handle_aggregated_exnl_rt(struct ospf6 *ospf6,
/* Handling the case where the external route prefix
* and aggegate prefix is same
* If same dont flush the originated external LSA.
*/
if (prefix_same(&aggr->p, &rt->prefix)) {
if (IS_OSPF6_DEBUG_AGGR)
- zlog_debug("%s: External Route prefix same as Aggregator(%pFX), so dont flush.",
+ zlog_debug("%s: External Route prefix same as Aggregator(%pFX), so don't flush.",
__func__,
&rt->prefix);
@@ -3623,7 +3623,7 @@ void ospf6_handle_external_lsa_origination(struct ospf6 *ospf6,
/* Handling the case where the
* external route prefix
* and aggegate prefix is same
* If same dont flush the
* originated
* external LSA.
*/
@@ -2874,7 +2874,7 @@ ospf6_originate_summary_lsa(struct ospf6 *ospf6,
zlog_debug("%s: Aggr LSA ID: %d flags %x.",
__func__, aggr->id, aggr->aggrflags);
- /* Dont originate external LSA,
+ /* Don't originate external LSA,
* If it is configured not to advertise.
*/
@@ -3248,11 +3248,11 @@ static void ospf6_handle_aggregated_exnl_rt(struct ospf6 *ospf6,
/* Handling the case where the external route prefix
* and aggegate prefix is same
- * If same dont flush the originated external LSA.
+ * If same don't flush the originated external LSA.
*/
if (prefix_same(&aggr->p, &rt->prefix)) {
@@ -3623,7 +3623,7 @@ void ospf6_handle_external_lsa_origination(struct ospf6 *ospf6,
* external route prefix
* and aggegate prefix is same
- * If same dont flush the
+ * If same don't flush the
* originated
* external LSA.